==> pytest-cookies_0.2.0.orig.tar.gz: pytest-cookies-0.2.0/docs/index.md <==
# Welcome to Pytest-Cookies

[![Join Chat on Gitter.im][gitter_badge]][gitter]

[pytest] is a mature full-featured Python testing tool that provides easy
no boilerplate testing. Its hook-baesd customization system supports integration
of external plugins such as **pytest-cookies**.

This plugin comes with a ``cookies`` fixture which is a wrapper for the
[cookiecutter] API for generating projects. It helps you verify that your
template is working as expected and takes care of cleaning up after running the
tests.

## GitHub Project

[https://github.com/hackebrot/pytest-cookies](https://github.com/hackebrot/pytest-cookies)

![Cookiecutter Logo](https://raw.github.com/audreyr/cookiecutter/aa309b73bdc974788ba265d843a65bb94c2e608e/cookiecutter_medium.png)

  [gitter_badge]: https://badges.gitter.im/Join%20Chat.svg
  [gitter]: https://gitter.im/hackebrot/pytest-cookies?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge
  [travis_badge]: https://travis-ci.org/hackebrot/pytest-cookies.svg?branch=master
  [travis]: https://travis-ci.org/hackebrot/pytest-cookies
  [appveyor_badge]: https://ci.appveyor.com/api/projects/status/github/hackebrot/pytest-cookies?branch=master
  [appveyor]: https://ci.appveyor.com/project/hackebrot/pytest-cookies/branch/master
  [docs_badge]: https://readthedocs.org/projects/pytest-cookies/badge/?version=latest
  [documentation]: http://pytest-cookies.readthedocs.org/en/latest/?badge=latest
  [pytest]: https://github.com/pytest-dev/pytest
  [cookiecutter]: https://github.com/audreyr/cookiecutter

==> pytest-cookies_0.4.0.orig.tar.gz: pytest-cookies-0.4.0/docs/index.md <==
# Welcome to Pytest-Cookies

[![Join Chat on Gitter.im][gitter_badge]][gitter]

[pytest] is a mature full-featured Python testing tool that provides easy
no boilerplate testing. Its hook-based customization system supports integration
of external plugins such as **pytest-cookies**.

This plugin comes with a ``cookies`` fixture which is a wrapper for the
[cookiecutter] API for generating projects. It helps you verify that your
template is working as expected and takes care of cleaning up after running the
tests.

## GitHub Project

[https://github.com/hackebrot/pytest-cookies](https://github.com/hackebrot/pytest-cookies)

![Cookiecutter Logo](https://raw.github.com/audreyr/cookiecutter/aa309b73bdc974788ba265d843a65bb94c2e608e/cookiecutter_medium.png)

  [gitter_badge]: https://badges.gitter.im/Join%20Chat.svg
  [gitter]: https://gitter.im/hackebrot/pytest-cookies?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge
  [travis_badge]: https://travis-ci.org/hackebrot/pytest-cookies.svg?branch=master
  [travis]: https://travis-ci.org/hackebrot/pytest-cookies
  [appveyor_badge]: https://ci.appveyor.com/api/projects/status/github/hackebrot/pytest-cookies?branch=master
  [appveyor]: https://ci.appveyor.com/project/hackebrot/pytest-cookies/branch/master
  [docs_badge]: https://readthedocs.org/projects/pytest-cookies/badge/?version=latest
  [documentation]: http://pytest-cookies.readthedocs.org/en/latest/?badge=latest
  [pytest]: https://github.com/pytest-dev/pytest
  [cookiecutter]: https://github.com/audreyr/cookiecutter
